@@ -39,7 +39,7 @@ JOB_STATE_CODES = {
 
 
 class SlurmQueue(SimQueue, ProtocolInterface):
-    """ Queue system for SLURM
+    """Queue system for SLURM
 
     Parameters
     ----------
@@ -320,14 +320,10 @@ class SlurmQueue(SimQueue, ProtocolInterface):
 
             # Move completed trajectories
             if self.datadir is not None:
-                datadir = os.path.abspath(self.datadir)
-                if not os.path.isdir(datadir):
-                    os.mkdir(datadir)
                 simname = os.path.basename(os.path.normpath(workdir))
-                # create directory for new file
-                odir = os.path.join(datadir, simname)
-                os.mkdir(odir)
-                f.write("\nmv *.{} {}".format(self.trajext, odir))
+                datadir = os.path.abspath(os.path.join(self.datadir, simname))
+                os.makedirs(datadir, exist_ok=True)
+                f.write(f"\nmv *.{self.trajext} {datadir}")
 
         os.chmod(fname, 0o700)
 
@@ -343,7 +339,7 @@ class SlurmQueue(SimQueue, ProtocolInterface):
         )
 
     def submit(self, dirs):
-        """ Submits all directories
+        """Submits all directories
 
         Parameters
         ----------
@@ -394,7 +390,7 @@ class SlurmQueue(SimQueue, ProtocolInterface):
         return ret
 
     def inprogress(self):
-        """ Returns the sum of the number of running and queued workunits of the specific group in the engine.
+        """Returns the sum of the number of running and queued workunits of the specific group in the engine.
 
         Returns
         -------
@@ -442,8 +438,7 @@ class SlurmQueue(SimQueue, ProtocolInterface):
         return inprog
 
     def stop(self):
-        """ Cancels all currently running and queued jobs
-        """
+        """Cancels all currently running and queued jobs"""
         if self.jobname is None:
             raise ValueError("The jobname needs to be defined.")
 
